@@ -1,22 +1,21 @@
-/*  Common Multimedia Command (MMC) routines.
+/* Common Multimedia Command (MMC) routines.
 
-    $Id: mmc.c,v 1.35 2006/10/11 12:38:18 rocky Exp $
+  $Id: mmc.c,v 1.40 2008/05/09 09:54:39 edsdead Exp $
 
-    Copyright (C) 2004, 2005, 2006 Rocky Bernstein <rocky@cpan.org>
+  Copyright (C) 2004, 2005, 2006, 2007, 2008 Rocky Bernstein <rocky@gnu.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -950,6 +949,21 @@ mmc_run_cmd( const CdIo_t *p_cdio, unsigned int i_timeout_ms,
 				     p_cdb, e_direction, i_buf, p_buf);
 }
 
+/* Added by SukkoPera to allow CDB length to be specified manually */
+driver_return_code_t
+mmc_run_cmd_len( const CdIo_t *p_cdio, unsigned int i_timeout_ms,
+                  const mmc_cdb_t *p_cdb, unsigned int i_cdb,
+                  cdio_mmc_direction_t e_direction, unsigned int i_buf,
+                  /*in/out*/ void *p_buf )
+{
+  if (!p_cdio) return DRIVER_OP_UNINIT;
+  if (!p_cdio->op.run_mmc_cmd) return DRIVER_OP_UNSUPPORTED;
+  return p_cdio->op.run_mmc_cmd(p_cdio->env, i_timeout_ms,
+                                     i_cdb,
+                                     p_cdb, e_direction, i_buf, p_buf);
+}
+
+
 /*! Return the byte size returned on a MMC READ command (e.g. READ_10,
     READ_MSF, ..)
 */
@@ -1278,7 +1292,6 @@ mmc_read_cd ( const CdIo_t *p_cdio, void *p_buf, lsn_t i_lsn,
   mmc_cdb_t cdb = {{0, }};
 
   mmc_run_cmd_fn_t run_mmc_cmd;
-  uint8_t i_read_type = 0;
   uint8_t cdb9 = 0;
 
   if (!p_cdio) return DRIVER_OP_UNINIT;
@@ -1286,14 +1299,9 @@ mmc_read_cd ( const CdIo_t *p_cdio, void *p_buf, lsn_t i_lsn,
 
   run_mmc_cmd = p_cdio->op.run_mmc_cmd;
 
-  CDIO_MMC_SET_COMMAND(cdb.field, CDIO_MMC_GPCMD_READ_CD);
-
-  i_read_type = read_sector_type << 2;
-  if (b_digital_audio_play) i_read_type |= 0x2;
-  
-  CDIO_MMC_SET_READ_TYPE    (cdb.field, i_read_type);
-  CDIO_MMC_SET_READ_LENGTH24(cdb.field, i_blocks);
-
+  CDIO_MMC_SET_COMMAND  (cdb.field, CDIO_MMC_GPCMD_READ_CD);
+  CDIO_MMC_SET_READ_TYPE(cdb.field, read_sector_type);
+  if (b_digital_audio_play) cdb.field[1] |= 0x2;
   
   if (b_sync)      cdb9 |= 128;
   if (b_user_data) cdb9 |=  16;
@@ -1313,7 +1321,8 @@ mmc_read_cd ( const CdIo_t *p_cdio, void *p_buf, lsn_t i_lsn,
         ? MAX_CD_READ_BLOCKS : i_blocks;
       void *p_buf2 = ((char *)p_buf ) + (j * i_blocksize);
       
-      CDIO_MMC_SET_READ_LBA (cdb.field, (i_lsn+j));
+      CDIO_MMC_SET_READ_LBA     (cdb.field, (i_lsn+j));
+      CDIO_MMC_SET_READ_LENGTH24(cdb.field, i_blocks2);
 
       i_ret = run_mmc_cmd (p_cdio->env, CD_READ_TIMEOUT_MS,
                            i_cdb, &cdb, 
@@ -1347,7 +1356,7 @@ mmc_read_data_sectors ( CdIo_t *p_cdio, void *p_buf,
                      true,  /* return user data */
                      false, /* return EDC ECC */
                      false, /* return C2 Error information */
-                     0,     /* suchannel selection bits */
+                     0,     /* subchannel selection bits */
                      ISO_BLOCKSIZE, /* blocksize*/ 
                      i_blocks       /* Number of blocks. */);
 
