@@ -1,53 +1,24 @@
 /*
- * Copyright (C) 2004, 2005, 2006, 2007 Rocky Bernstein <rocky@gnu.org>
- *           (C) 1998 Monty <xiphmont@mit.edu>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2, or (at your option)
- *   any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- *   02110-1301 USA.
- *
- *
- * See ChangeLog for recent changes.
- *
- * last changes:
- *   22.01.98 - first version
- *   15.02.98 - alpha 2: juggled two includes from interface/low_interface.h
- *                       that move contents in Linux 2.1
- *                       Linked status bar to isatty to avoid it appearing
- *                       in a redirected file.
- *                       Played with making TOC less verbose.
- *   04.04.98 - alpha 3: zillions of bugfixes, also added MMC and IDE_SCSI
- *                       emulation support
- *   05.04.98 - alpha 4: Segfault fix, cosmetic repairs
- *   05.04.98 - alpha 5: another segfault fix, cosmetic repairs, 
- *                       Gadi Oxman provided code to identify/fix nonstandard
- *                       ATAPI CDROMs 
- *   07.04.98 - alpha 6: Bugfixes to autodetection
- *   18.06.98 - alpha 7: Additional SCSI error handling code
- *                       cosmetic fixes
- *                       segfault fixes
- *                       new sync/silence code, smaller fft      
- *   15.07.98 - alpha 8: More new SCSI code, better error recovery
- *                       more segfault fixes (two linux bugs, one my fault)
- *                       Fixup reporting fixes, smilie fixes.
- *                       AIFF support (in addition to AIFC)
- *                       Path parsing fixes
- *   Changes are becoming TNTC. Will resume the log at beta.
- *
- *   09.04.04 - conversion to use libcdio. See top-level Changelog for
- *              libcdio history.
- */
+  $Id: cd-paranoia.c,v 1.37 2008/06/19 15:44:30 flameeyes Exp $
+
+  Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Rocky Bernstein <rocky@gnu.org>
+            (C) 1998 Monty <xiphmont@mit.edu>
+
+  This program is free software: you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
+
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+  See ChangeLog for recent changes.
+*/
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -144,7 +115,7 @@ parse_offset(cdrom_drive_t *d, char *offset, int begin)
 
   if (!offset) return -1;
 
-  /* seperate track from time offset */
+  /* separate track from time offset */
   temp=strchr(offset,']');
   if(temp){
     *temp='\0';
@@ -311,12 +282,13 @@ static void usage(FILE *f)
   fprintf( f, usage_help);
 }
 
-long callbegin;
-long callend;
-long callscript=0;
+static long callbegin;
+static long callend;
+static long callscript=0;
 
 static int skipped_flag=0;
 static int abort_on_skip=0;
+static FILE *logfile = NULL;
 
 #if TRACE_PARANOIA
 static void
@@ -368,10 +340,11 @@ callback(long int inpos, paranoia_cb_mode_t function)
   static int stimeout=0;
   const char *smilie="= :-)";
   
-  if(callscript)
-    fprintf(stderr,"##: %d [%s] @ %ld\n",
-	    function,(function>=-2&&function<=13?callback_strings[function+2]:
-		      ""),inpos);
+  if (callscript)
+    fprintf(stderr, "##: %d [%s] @ %ld\n",
+	    function, ((int) function >= -2 && (int) function <= 13 ?
+		       callback_strings[function+2] : ""),
+	    inpos);
 
   if(!quiet){
     long test;
@@ -555,7 +528,14 @@ callback(long int inpos, paranoia_cb_mode_t function)
 	    buffer[aheadposition+19]='>';
 	}
    
-	fprintf(stderr,buffer);
+ 	if(isatty(STDERR_FILENO))
+	    fprintf(stderr, "%s", buffer);
+
+	if (logfile != NULL && function==-1) {
+	  fprintf(logfile, "%s", buffer+1);
+	  fprintf(logfile,"\n\n");
+	  fflush(logfile);
+	}
       }
     }
   }
@@ -566,9 +546,9 @@ callback(long int inpos, paranoia_cb_mode_t function)
 }
 #endif /* !TRACE_PARANOIA */
 
-const char *optstring = "aBcCd:efg:hi:m:n:o:O:pqQrRsS:Tt:VvwWx:XYZz::";
+static const char optstring[] = "aBcCd:efg:hi:l:m:n:o:O:pqQrRsS:Tt:VvwWx:XYZz::";
 
-struct option options [] = {
+static const struct option options [] = {
 	{"abort-on-skip",             no_argument,       NULL, 'X'},
 	{"batch",                     no_argument,       NULL, 'B'},
 	{"disable-extra-paranoia",    no_argument,       NULL, 'Y'},
@@ -582,11 +562,11 @@ struct option options [] = {
 	{"force-read-speed",          required_argument, NULL, 'S'},
 	{"force-search-overlap",      required_argument, NULL, 'o'},
 	{"help",                      no_argument,       NULL, 'h'},
+ 	{"log-summary",               required_argument, NULL, 'l'},
 	{"mmc-timeout",               required_argument, NULL, 'm'},
 	{"never-skip",                optional_argument, NULL, 'z'},
 	{"output-aifc",               no_argument,       NULL, 'a'},
 	{"output-aiff",               no_argument,       NULL, 'f'},
-	{"output-info",               required_argument, NULL, 'i'},
 	{"output-raw",                no_argument,       NULL, 'p'},
 	{"output-raw-big-endian",     no_argument,       NULL, 'R'},
 	{"output-raw-little-endian",  no_argument,       NULL, 'r'},
@@ -609,7 +589,6 @@ static cdrom_drive_t    *d        = NULL;
 static cdrom_paranoia_t *p        = NULL;
 static char             *span     = NULL;
 static char *force_cdrom_device   = NULL;
-static char *info_file            = NULL;
 
 #define free_and_null(p) \
   free(p);		 \
@@ -636,7 +615,10 @@ cleanup (void)
   if (d) cdda_close(d);
   free_and_null(force_cdrom_device);
   free_and_null(span);
-  free_and_null(info_file);
+  if(logfile && logfile != stdout) {
+      fclose(logfile);
+      logfile = NULL;
+    }
 }
 
 /* Returns true if we have an integer argument. 
@@ -742,9 +724,18 @@ main(int argc,char *argv[])
     case 'h':
       usage(stdout);
       exit(0);
-    case 'i':
-      if(info_file)free(info_file);
-      info_file=strdup(info_file);
+    case 'l':
+      if(logfile && logfile != stdout)fclose(logfile);
+      if(!strcmp(optarg,"-"))
+	logfile=stdout;
+      else{
+	logfile=fopen(optarg,"w");
+	if(logfile==NULL){
+	  report3("Cannot open log summary file %s: %s",(char*)optarg,
+		  strerror(errno));
+	  exit(1);
+	}
+      }
       break;
     case 'm':
       {
@@ -838,6 +829,18 @@ main(int argc,char *argv[])
       exit(1);
     }
   }
+  
+  if(logfile){
+    /* log command line and version */
+    int i;
+    for (i = 0; i < argc; i++) 
+      fprintf(logfile,"%s ",argv[i]);
+    fprintf(logfile,"\n");
+    
+    fprintf(logfile,VERSION);
+    fprintf(logfile,"\n");
+    fflush(logfile);
+  }
 
   if(optind>=argc && !query_only){
     if(batch)
@@ -918,6 +921,8 @@ main(int argc,char *argv[])
       report("Search overlap sectors must be 0<= n <=75\n");
       cdda_close(d);
       d=NULL;
+      if(logfile && logfile != stdout)
+        fclose(logfile);
       exit(1);
     }
     {
@@ -1137,6 +1142,10 @@ main(int argc,char *argv[])
 	      report("Are you sure you wanted 'batch' "
 		     "(-B) output with stdout?");
 	    report("outputting to stdout\n");
+	    if(logfile){
+	      fprintf(logfile,"outputting to stdout\n");
+	      fflush(logfile);
+	    }
 	    outfile_name[0]='\0';
 	  } else {
 	    char path[256];
@@ -1180,6 +1189,10 @@ main(int argc,char *argv[])
 	      exit(1);
 	    }
 	    report2("outputting to %s\n", outfile_name);
+	    if(logfile){
+	      fprintf(logfile,"outputting to %s\n",outfile_name);
+	      fflush(logfile);
+	    }
 	  }
 	} else {
 	  /* default */
@@ -1210,6 +1223,11 @@ main(int argc,char *argv[])
 	    exit(1);
 	  }
 	  report2("outputting to %s\n", outfile_name);
+	  if(logfile){
+	    fprintf(logfile,"outputting to %s\n",outfile_name);
+	    fflush(logfile);
+	  }
+
 	}
 	
 	switch(output_type) {
