@@ -1,21 +1,20 @@
 /*
-  $Id: util.c,v 1.52 2007/10/21 21:57:09 rocky Exp $
+  $Id: util.c,v 1.54 2008/04/14 17:30:27 karl Exp $
 
-  Copyright (C) 2003, 2004, 2005, 2007 Rocky Bernstein <rocky@gnu.org>
+  Copyright (C) 2003, 2004, 2005, 2007, 2008, 2009 Rocky Bernstein <rocky@gnu.org>
   
-  This program is free software; you can redistribute it and/or modify
+  This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
+  the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 /* Miscellaneous things common to standalone programs. */
@@ -46,11 +45,9 @@ print_version (char *program_name, const char *version,
 	       int no_header, bool version_only)
 {
   
-  driver_id_t driver_id;
-
   if (no_header == 0)
     report( stdout,  
-	    "%s version %s\nCopyright (c) 2003, 2004, 2005, 2007 R. Bernstein\n",
+	    "%s version %s\nCopyright (c) 2003, 2004, 2005, 2007, 2008 R. Bernstein\n",
 	    program_name, version);
   report( stdout,  
 	  _("This is free software; see the source for copying conditions.\n\
@@ -60,9 +57,10 @@ PARTICULAR PURPOSE.\n\
 
   if (version_only) {
     char *default_device;
-    for (driver_id=DRIVER_UNKNOWN+1; driver_id<=CDIO_MAX_DRIVER; driver_id++) {
-      if (cdio_have_driver(driver_id)) {
-	report( stdout, "Have driver: %s\n", cdio_driver_describe(driver_id));
+    const driver_id_t *driver_id_p;
+    for (driver_id_p=cdio_drivers; *driver_id_p!=DRIVER_UNKNOWN; driver_id_p++) {
+      if (cdio_have_driver(*driver_id_p)) {
+	report( stdout, "Have driver: %s\n", cdio_driver_describe(*driver_id_p));
       }
     }
     default_device=cdio_get_default_device(NULL);
@@ -161,7 +159,7 @@ open_input(const char *psz_source, source_image_t source_image,
 char *
 fillout_device_name(const char *device_name) 
 {
-#if defined(HAVE_WIN32_CDROM)
+#if defined(HAVE_WIN32_CDROM) || defined(HAVE_OS2_CDROM)
   return strdup(device_name);
 #else
   unsigned int prefix_len = strlen(DEV_PREFIX);
